@@ -3,7 +3,6 @@
 This module contains model-specific result dataclasses:
 - DFMResult(BaseResult): Results for linear DFM
 - DDFMResult(BaseResult): Results for Deep DFM
-- KDFMResult(BaseResult): Results for Kernelized DFM
 """
 
 import numpy as np
@@ -14,7 +13,7 @@ from typing import Optional, List, Dict, Any, Tuple
 from datetime import datetime
 
 from .model import DFMConfig
-from .params import DFMFitParams, DDFMFitParams
+from .params import DDFMModelState
 
 
 
@@ -236,15 +235,12 @@ class DFMResult(BaseResult):
         Whether EM algorithm converged.
     num_iter : int
         Number of EM iterations performed.
-    fit_params : DFMFitParams, optional
-        Fit-time parameter overrides used during estimation.
-        Contains: max_iter, threshold, regularization_scale
     training_max_iter : int, optional
-        Maximum EM iterations used (from model.max_iter or fit_params.max_iter)
+        Maximum EM iterations used (from model.max_iter or config.max_iter)
     training_threshold : float, optional
-        Convergence threshold used (from model.threshold or fit_params.threshold)
+        Convergence threshold used (from model.threshold or config.threshold)
     training_regularization_scale : float, optional
-        Regularization scale used (from fit_params.regularization_scale if provided)
+        Regularization scale used (from config.regularization if provided)
     
     Examples
     --------
@@ -264,8 +260,7 @@ class DFMResult(BaseResult):
     # All fields inherited from BaseResult
     # converged and num_iter have specific meaning for EM algorithm
     
-    # Fit-time parameters
-    fit_params: Optional[DFMFitParams] = None
+    # Training hyperparameters (from config, no separate fit_params needed)
     training_max_iter: Optional[int] = None
     training_threshold: Optional[float] = None
     training_regularization_scale: Optional[float] = None
@@ -316,7 +311,7 @@ class DDFMResult(BaseResult):
         Architecture of the encoder network used.
     use_idiosyncratic : bool, optional
         Whether idiosyncratic components were modeled.
-    fit_params : DDFMFitParams, optional
+    fit_params : DDFMModelState, optional
         State-space model parameters created during fit (F, Q, mu_0, sigma_0, H, R).
         These are computed during build_state_space() and represent the fitted
         state-space model structure.
@@ -369,8 +364,8 @@ class DDFMResult(BaseResult):
     encoder_layers: Optional[List[int]] = None  # Encoder architecture
     use_idiosyncratic: Optional[bool] = None  # Whether idio components were used
     
-    # Fit-time parameters (state-space model)
-    fit_params: Optional[DDFMFitParams] = None
+    # State-space parameters (fitted during training)
+    fit_params: Optional[DDFMModelState] = None
     
     # Training hyperparameters
     training_max_iter: Optional[int] = None
@@ -427,66 +422,5 @@ class DDFMResult(BaseResult):
         
         return "\n".join(lines)
 
-@dataclass
-class KDFMResult(BaseResult):
-    """KDFM estimation results structure.
-    
-    This dataclass contains all outputs from the KDFM estimation procedure,
-    including estimated parameters, smoothed data, and factors.
-    
-    Inherits all fields and methods from BaseResult. This class is specifically
-    for KDFM results estimated using gradient descent.
-    
-    Attributes
-    ----------
-    S : np.ndarray, optional
-        Structural identification matrix (K x K)
-    structural_shocks : np.ndarray, optional
-        Structural shocks ε_t (T x K)
-    irf_reduced : np.ndarray, optional
-        Reduced-form IRFs (horizon x K x K)
-    irf_structural : np.ndarray, optional
-        Structural IRFs (horizon x K x K)
-    ar_coeffs : np.ndarray, optional
-        Extracted VAR coefficients (p x K x K)
-    ma_coeffs : np.ndarray, optional
-        Extracted MA coefficients (q x K x K), only if q > 0
-    """
-    # KDFM-specific fields
-    S: Optional[np.ndarray] = None  # Structural identification matrix
-    structural_shocks: Optional[np.ndarray] = None  # ε_t (T x K)
-    irf_reduced: Optional[np.ndarray] = None  # Reduced-form IRFs
-    irf_structural: Optional[np.ndarray] = None  # Structural IRFs
-    ar_coeffs: Optional[np.ndarray] = None  # Extracted VAR coefficients
-    ma_coeffs: Optional[np.ndarray] = None  # Extracted MA coefficients (if q > 0)
-    
-    def summary(self) -> str:
-        """Return a formatted summary of the KDFM results."""
-        summary_text = super().summary()
-        lines = summary_text.split("\n")
-        
-        # Insert KDFM-specific information before the final separator
-        insert_idx = len(lines) - 1
-        kdfm_info = []
-        
-        if self.ar_coeffs is not None:
-            ar_order = self.ar_coeffs.shape[0] if self.ar_coeffs.ndim > 0 else 0
-            kdfm_info.append(f"  VAR order: {ar_order}")
-        if self.ma_coeffs is not None:
-            ma_order = self.ma_coeffs.shape[0] if self.ma_coeffs.ndim > 0 else 0
-            kdfm_info.append(f"  MA order: {ma_order}")
-        if self.irf_reduced is not None:
-            kdfm_info.append("  IRFs computed: Reduced-form")
-        if self.irf_structural is not None:
-            kdfm_info.append("  IRFs computed: Structural")
-        
-        if kdfm_info:
-            lines.insert(insert_idx, "")
-            lines.insert(insert_idx, "KDFM-Specific:")
-            for info in kdfm_info:
-                lines.insert(insert_idx + 1, info)
-        
-        return "\n".join(lines)
-
 # FitParams moved to config.schema.params as DFMParams
 
